@@ -2,11 +2,27 @@ package Wasm::Memory;
 
 use strict;
 use warnings;
+use Wasm::Wasmtime::Caller ();
+use base qw( Exporter );
+
+our @EXPORT_OK = qw( wasm_caller_memory );
 
 # ABSTRACT: Interface to WebAssembly Memory
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
+sub wasm_caller_memory
+{
+  my $caller = Wasm::Wasmtime::Caller::wasmtime_caller();
+  defined $caller
+    ? do {
+      my $wm = $caller->export_get('memory');
+      defined $wm && $wm->is_memory
+        ? __PACKAGE__->new($wm)
+        : undef;
+    } : undef;
+}
+
 sub new
 {
   my($class, $memory) = @_;
@@ -47,10 +63,12 @@ Wasm::Memory - Interface to WebAssembly Memory
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
+Use WebAssembly memory from plain Perl:
+
  use PeekPoke::FFI qw( peek poke );
  use Wasm
    -api => 0,
@@ -79,12 +97,59 @@ version 0.11
  printf "min     = %d\n", $min;                  # 3
  printf "max     = %d\n", $max;                  # 9
 
+Use WebAssembly memory from Perl in callback from WebAssembly:
+
+ use Wasm::Memory qw( wasm_caller_memory );
+ 
+ {
+   # this just uses Platypus to create a utility function
+   # to convert a pointer to a C string into a Perl string.
+   use FFI::Platypus 1.00;
+   my $ffi = FFI::Platypus->new( api => 1 );
+   $ffi->attach_cast( 'cstring' => 'opaque' => 'string' );
+ }
+ 
+ sub print_wasm_string
+ {
+   my $ptr = shift;
+   my $memory = wasm_caller_memory;
+   print cstring($ptr + $memory->address);
+ }
+ 
+ use Wasm
+   -api => 0,
+   -wat => q{
+     (module
+       (import "main" "print_wasm_string" (func $print_wasm_string (param i32)))
+       (func (export "run")
+         i32.const 0
+         call $print_wasm_string
+       )
+       (memory (export "memory") 1)
+       (data (i32.const 0) "Hello, world!\n\00")
+     )
+   },
+ ;
+ 
+ run();
+
 =head1 DESCRIPTION
 
 This class represents a region of memory exported from a WebAssembly
 module.  A L<Wasm::Memory> instance is automatically imported into
 Perl space for each WebAssembly memory region with the same name.
 
+=head1 FUNCTIONS
+
+=head2 wasm_caller_memory
+
+ my $memory = wasm_caller_memory;
+
+Returns the memory region of the WebAssembly caller, if Perl has been
+called by Wasm, otherwise it returns C<undef>.
+
+This function can be exported by request via L<Exporter>.
+
 =head1 METHODS
 
 =head2 address
